@@ -58,7 +58,7 @@ impl<'a> ParallelCommand<'a> {
                 Token::Number(job, token) => {
                     // The `token` is a pointer which needs to be unboxed.
                     let raw_token = Box::into_raw(token);
-                    let input = &jobs[job];
+                    let input = &jobs[job-1];
 
                     unsafe {
                         // Match the associated token to be used with the job number.
@@ -317,8 +317,10 @@ fn build_arguments_test() {
         command_template: &tokens,
     };
 
+    let jobs = ["one".to_owned(), "two".to_owned(), "three".to_owned()];
+
     let mut arguments = String::new();
-    command.build_arguments(&mut arguments);
+    command.build_arguments(&mut arguments, &jobs[..]);
     assert_eq!(arguments, String::from("-i applesauce.mp4 applesauce.mkv"))
 }
 
